import { EntityManager } from '@mikro-orm/core';
import * as Faker from 'faker';
import { FactoryContainer } from './factory-container';
/**
 * @abstract
 * @class EntityFactory
 * @summary
 * The Abstract EntityFactory is the class that all registered
 * factories must extend to produce entities.
 *
 * @typeparam E: The Entity that the factory generates
 */
export declare abstract class EntityFactory<E> {
    private readonly em;
    protected readonly container: FactoryContainer;
    protected readonly faker: typeof Faker;
    /**
     * @constructor
     * @property em: MikroORM Entity Manager
     * @property container: The factory container
     * acts parent reference for using other factories within a factory
     * @property faker: Faker library for having stub data
     */
    constructor(em: EntityManager, container: FactoryContainer, faker?: typeof Faker);
    /**
     * @abstract
     * @public
     * @summary
     * The make function defines how to create an instance
     * of type E. makeOne, makeMany call this function to
     * generate an entity.
     *
     * @param overrides: Params to override object with
     * @returns an instance of E
     */
    abstract make(overrides?: Partial<E>): Promise<E>;
    /**
     * @public
     * @summary
     * Create and insert many entities into the database
     *
     * @param count: The number of entities to save (default is 1)
     * @param overrides: The object to override with - passed down into make
     * @returns An array of saved entities
     */
    saveMany(count?: number, overrides?: Partial<E>): Promise<E[]>;
    /**
     * @public
     * @summary
     * Create and insert one entity into the database
     *
     * @param overrides: The object to override with - passed down into make()
     * @returns An entity
     */
    saveOne(overrides?: Partial<E>): Promise<E>;
}
